==> zio-aws-lookoutequipment_2.12-5.17.145.1-sources.jar: zio/aws/lookoutequipment/model/IngestionJobStatus.scala <==
package zio.aws.lookoutequipment.model
import scala.jdk.CollectionConverters._
sealed trait IngestionJobStatus {
  def unwrap: software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus
}
object IngestionJobStatus {
  def wrap(
      value: software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus
  ): zio.aws.lookoutequipment.model.IngestionJobStatus = value match {
    case software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.IN_PROGRESS =>
      val r = IN_PROGRESS
      r
    case software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.SUCCESS =>
      val r = SUCCESS
      r
    case software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.FAILED =>
      val r = FAILED
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.lookoutequipment.model.IngestionJobStatus {
    override def unwrap
        : software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus =
      software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object IN_PROGRESS
      extends zio.aws.lookoutequipment.model.IngestionJobStatus {
    override def unwrap
        : software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus =
      software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.IN_PROGRESS
  }
  case object SUCCESS
      extends zio.aws.lookoutequipment.model.IngestionJobStatus {
    override def unwrap
        : software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus =
      software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.SUCCESS
  }
  case object FAILED extends zio.aws.lookoutequipment.model.IngestionJobStatus {
    override def unwrap
        : software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus =
      software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.FAILED
  }
}

==> zio-aws-lookoutequipment_2.12-6.20.149.1-sources.jar: zio/aws/lookoutequipment/model/IngestionJobStatus.scala <==
package zio.aws.lookoutequipment.model
import scala.jdk.CollectionConverters._
sealed trait IngestionJobStatus {
  def unwrap: software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus
}
object IngestionJobStatus {
  def wrap(
      value: software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus
  ): zio.aws.lookoutequipment.model.IngestionJobStatus = value match {
    case software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.IN_PROGRESS =>
      val r = IN_PROGRESS
      r
    case software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.SUCCESS =>
      val r = SUCCESS
      r
    case software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.FAILED =>
      val r = FAILED
      r
    case software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.IMPORT_IN_PROGRESS =>
      val r = IMPORT_IN_PROGRESS
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.lookoutequipment.model.IngestionJobStatus {
    override def unwrap
        : software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus =
      software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object IN_PROGRESS
      extends zio.aws.lookoutequipment.model.IngestionJobStatus {
    override def unwrap
        : software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus =
      software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.IN_PROGRESS
  }
  case object SUCCESS
      extends zio.aws.lookoutequipment.model.IngestionJobStatus {
    override def unwrap
        : software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus =
      software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.SUCCESS
  }
  case object FAILED extends zio.aws.lookoutequipment.model.IngestionJobStatus {
    override def unwrap
        : software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus =
      software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.FAILED
  }
  case object IMPORT_IN_PROGRESS
      extends zio.aws.lookoutequipment.model.IngestionJobStatus {
    override def unwrap
        : software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus =
      software.amazon.awssdk.services.lookoutequipment.model.IngestionJobStatus.IMPORT_IN_PROGRESS
  }
}
